[jboss-cvs] JBossCache/tests/functional/org/jboss/cache/loader ...
Manik Surtani
manik at jboss.org
Thu Jul 12 10:29:04 EDT 2007
User: msurtani
Date: 07/07/12 10:29:04
Modified: tests/functional/org/jboss/cache/loader
UnnecessaryLoadingTest.java
Log:
Better method naming
Revision Changes Path
1.2 +5 -5 JBossCache/tests/functional/org/jboss/cache/loader/UnnecessaryLoadingTest.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: UnnecessaryLoadingTest.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/tests/functional/org/jboss/cache/loader/UnnecessaryLoadingTest.java,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -b -r1.1 -r1.2
--- UnnecessaryLoadingTest.java 12 Jul 2007 14:26:34 -0000 1.1
+++ UnnecessaryLoadingTest.java 12 Jul 2007 14:29:04 -0000 1.2
@@ -123,15 +123,15 @@
cache.put(child, k, v);
// nodes should be marked as having data loaded.
- assertTrue(cache.peek(parent, false).getDataLoaded());
- assertTrue(cache.peek(child, false).getDataLoaded());
+ assertTrue(cache.peek(parent, false).isDataLoaded());
+ assertTrue(cache.peek(child, false).isDataLoaded());
// now evict the parent
cache.evict(parent, false);
- // only the evicted parent should have getDataLoaded() set to false. Not the child.
- assertFalse(cache.peek(parent, false).getDataLoaded());
- assertTrue(cache.peek(child, false).getDataLoaded());
+ // only the evicted parent should have isDataLoaded() set to false. Not the child.
+ assertFalse(cache.peek(parent, false).isDataLoaded());
+ assertTrue(cache.peek(child, false).isDataLoaded());
assertNotNull(cache.peek(child, false));
// there is no REAL cache loader so this return value should not be tested
More information about the jboss-cvs-commits
mailing list